# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/warehouse_picker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fv1/stock/warehouse_picker.proto\x12*pro.omni.oms.api.v1.stock.warehouse_picker\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x95\x02\n\x0fWarehousePicker\x12\n\n\x02id\x18\x01 \x01(\x05\x12*\n\twarehouse\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04pick\x18\x03 \x01(\x05\x12\x0c\n\x04pack\x18\x04 \x01(\x05\x12\x0b\n\x03out\x18\x05 \x01(\x05\x12\x10\n\x08returned\x18\x06 \x01(\x05\x12\x10\n\x08internal\x18\x07 \x01(\x05\x12\x10\n\x08incoming\x18\x08 \x01(\x05\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x02\n\x1aWarehousePickerReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfb\x01\n\x1bWarehousePickerReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12V\n\x11warehouse_pickers\x18\x03 \x03(\x0b\x32;.pro.omni.oms.api.v1.stock.warehouse_picker.WarehousePicker2\xc3\x01\n\x16WarehousePickerService\x12\xa8\x01\n\x13WarehousePickerRead\x12\x46.pro.omni.oms.api.v1.stock.warehouse_picker.WarehousePickerReadRequest\x1aG.pro.omni.oms.api.v1.stock.warehouse_picker.WarehousePickerReadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.warehouse_picker_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEPICKER"]._serialized_start = 161
    _globals["_WAREHOUSEPICKER"]._serialized_end = 438
    _globals["_WAREHOUSEPICKERREADREQUEST"]._serialized_start = 441
    _globals["_WAREHOUSEPICKERREADREQUEST"]._serialized_end = 817
    _globals["_WAREHOUSEPICKERREADRESPONSE"]._serialized_start = 820
    _globals["_WAREHOUSEPICKERREADRESPONSE"]._serialized_end = 1071
    _globals["_WAREHOUSEPICKERSERVICE"]._serialized_start = 1074
    _globals["_WAREHOUSEPICKERSERVICE"]._serialized_end = 1269
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/picker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import category_pb2 as v1_dot_rules_dot_category__pb2
from omni.pro.protos.v1.rules import user_pb2 as v1_dot_rules_dot_user__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15v1/rules/picker.proto\x12 pro.omni.oms.api.v1.rules.picker\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x13v1/rules/user.proto\x1a\x17v1/rules/category.proto"a\n\x0e\x43\x61tegoryValues\x12\x15\n\rfamily_doc_id\x18\x01 \x01(\t\x12\x12\n\ngroup_code\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t"\xf1\x04\n\x06Picker\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.rules.user.User\x12\x41\n\twarehouse\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12@\n\ncategories\x18\x04 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12,\n\x08\x63\x61n_pick\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x63\x61n_pack\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_out\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_int\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x63\x61n_in\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncan_return\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06status\x18\x0b \x01(\t\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\r \x01(\t\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe1\x03\n\x13PickerCreateRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12I\n\x0f\x63\x61tegory_values\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.rules.picker.CategoryValues\x12,\n\x08\x63\x61n_pick\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x63\x61n_pack\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_out\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_int\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x63\x61n_in\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncan_return\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06status\x18\n \x01(\t\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x14PickerCreateResponse\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xef\x02\n\x11PickerReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x12PickerReadResponse\x12\x39\n\x07pickers\x18\x01 \x03(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x87\x01\n\x13PickerUpdateRequest\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x14PickerUpdateResponse\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"Y\n\x13PickerDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14PickerDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x8d\x04\n\rPickerService\x12\x7f\n\x0cPickerCreate\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerCreateRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerCreateResponse"\x00\x12y\n\nPickerRead\x12\x33.pro.omni.oms.api.v1.rules.picker.PickerReadRequest\x1a\x34.pro.omni.oms.api.v1.rules.picker.PickerReadResponse"\x00\x12\x7f\n\x0cPickerUpdate\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerUpdateRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerUpdateResponse"\x00\x12\x7f\n\x0cPickerDelete\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerDeleteRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.picker_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CATEGORYVALUES"]._serialized_start = 182
    _globals["_CATEGORYVALUES"]._serialized_end = 279
    _globals["_PICKER"]._serialized_start = 282
    _globals["_PICKER"]._serialized_end = 907
    _globals["_PICKERCREATEREQUEST"]._serialized_start = 910
    _globals["_PICKERCREATEREQUEST"]._serialized_end = 1391
    _globals["_PICKERCREATERESPONSE"]._serialized_start = 1394
    _globals["_PICKERCREATERESPONSE"]._serialized_end = 1549
    _globals["_PICKERREADREQUEST"]._serialized_start = 1552
    _globals["_PICKERREADREQUEST"]._serialized_end = 1919
    _globals["_PICKERREADRESPONSE"]._serialized_start = 1922
    _globals["_PICKERREADRESPONSE"]._serialized_end = 2135
    _globals["_PICKERUPDATEREQUEST"]._serialized_start = 2138
    _globals["_PICKERUPDATEREQUEST"]._serialized_end = 2273
    _globals["_PICKERUPDATERESPONSE"]._serialized_start = 2276
    _globals["_PICKERUPDATERESPONSE"]._serialized_end = 2431
    _globals["_PICKERDELETEREQUEST"]._serialized_start = 2433
    _globals["_PICKERDELETEREQUEST"]._serialized_end = 2522
    _globals["_PICKERDELETERESPONSE"]._serialized_start = 2524
    _globals["_PICKERDELETERESPONSE"]._serialized_end = 2621
    _globals["_PICKERSERVICE"]._serialized_start = 2624
    _globals["_PICKERSERVICE"]._serialized_end = 3149
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import category_pb2 as _category_pb2
from omni.pro.protos.v1.rules import user_pb2 as _user_pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as _warehouse_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class CategoryValues(_message.Message):
    __slots__ = ["family_doc_id", "group_code", "attribute_code", "code"]
    FAMILY_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_CODE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    family_doc_id: str
    group_code: str
    attribute_code: str
    code: str
    def __init__(
        self,
        family_doc_id: _Optional[str] = ...,
        group_code: _Optional[str] = ...,
        attribute_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
    ) -> None: ...

class Picker(_message.Message):
    __slots__ = [
        "id",
        "user",
        "warehouse",
        "categories",
        "can_pick",
        "can_pack",
        "can_out",
        "can_int",
        "can_in",
        "can_return",
        "status",
        "active",
        "external_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    CAN_PICK_FIELD_NUMBER: _ClassVar[int]
    CAN_PACK_FIELD_NUMBER: _ClassVar[int]
    CAN_OUT_FIELD_NUMBER: _ClassVar[int]
    CAN_INT_FIELD_NUMBER: _ClassVar[int]
    CAN_IN_FIELD_NUMBER: _ClassVar[int]
    CAN_RETURN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user: _user_pb2.User
    warehouse: _warehouse_pb2.Warehouse
    categories: _containers.RepeatedCompositeFieldContainer[_category_pb2.Category]
    can_pick: _wrappers_pb2.BoolValue
    can_pack: _wrappers_pb2.BoolValue
    can_out: _wrappers_pb2.BoolValue
    can_int: _wrappers_pb2.BoolValue
    can_in: _wrappers_pb2.BoolValue
    can_return: _wrappers_pb2.BoolValue
    status: str
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...,
        warehouse: _Optional[_Union[_warehouse_pb2.Warehouse, _Mapping]] = ...,
        categories: _Optional[_Iterable[_Union[_category_pb2.Category, _Mapping]]] = ...,
        can_pick: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_pack: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_out: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_int: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_in: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_return: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        status: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class PickerCreateRequest(_message.Message):
    __slots__ = [
        "user_id",
        "warehouse_id",
        "category_values",
        "can_pick",
        "can_pack",
        "can_out",
        "can_int",
        "can_in",
        "can_return",
        "status",
        "context",
    ]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_VALUES_FIELD_NUMBER: _ClassVar[int]
    CAN_PICK_FIELD_NUMBER: _ClassVar[int]
    CAN_PACK_FIELD_NUMBER: _ClassVar[int]
    CAN_OUT_FIELD_NUMBER: _ClassVar[int]
    CAN_INT_FIELD_NUMBER: _ClassVar[int]
    CAN_IN_FIELD_NUMBER: _ClassVar[int]
    CAN_RETURN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    warehouse_id: int
    category_values: _containers.RepeatedCompositeFieldContainer[CategoryValues]
    can_pick: _wrappers_pb2.BoolValue
    can_pack: _wrappers_pb2.BoolValue
    can_out: _wrappers_pb2.BoolValue
    can_int: _wrappers_pb2.BoolValue
    can_in: _wrappers_pb2.BoolValue
    can_return: _wrappers_pb2.BoolValue
    status: str
    context: _base_pb2.Context
    def __init__(
        self,
        user_id: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        category_values: _Optional[_Iterable[_Union[CategoryValues, _Mapping]]] = ...,
        can_pick: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_pack: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_out: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_int: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_in: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        can_return: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        status: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickerCreateResponse(_message.Message):
    __slots__ = ["picker", "response_standard"]
    PICKER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picker: Picker
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        picker: _Optional[_Union[Picker, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class PickerReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickerReadResponse(_message.Message):
    __slots__ = ["pickers", "meta_data", "response_standard"]
    PICKERS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    pickers: _containers.RepeatedCompositeFieldContainer[Picker]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        pickers: _Optional[_Iterable[_Union[Picker, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class PickerUpdateRequest(_message.Message):
    __slots__ = ["picker", "context"]
    PICKER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    picker: Picker
    context: _base_pb2.Context
    def __init__(
        self,
        picker: _Optional[_Union[Picker, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickerUpdateResponse(_message.Message):
    __slots__ = ["picker", "response_standard"]
    PICKER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picker: Picker
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        picker: _Optional[_Union[Picker, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class PickerDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class PickerDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/picking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import address_pb2 as v1_dot_stock_dot_address__pb2
from omni.pro.protos.v1.stock import attachment_pb2 as v1_dot_stock_dot_attachment__pb2
from omni.pro.protos.v1.stock import carrier_pb2 as v1_dot_stock_dot_carrier__pb2
from omni.pro.protos.v1.stock import client_pb2 as v1_dot_stock_dot_client__pb2
from omni.pro.protos.v1.stock import delivery_method_pb2 as v1_dot_stock_dot_delivery__method__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import order_pb2 as v1_dot_stock_dot_order__pb2
from omni.pro.protos.v1.stock import payment_method_pb2 as v1_dot_stock_dot_payment__method__pb2
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2
from omni.pro.protos.v1.stock import procurement_group_pb2 as v1_dot_stock_dot_procurement__group__pb2
from omni.pro.protos.v1.stock import sale_pb2 as v1_dot_stock_dot_sale__pb2
from omni.pro.protos.v1.stock import user_pb2 as v1_dot_stock_dot_user__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/stock/picking.proto\x12!pro.omni.oms.api.v1.stock.picking\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17v1/stock/location.proto\x1a\x1bv1/stock/picking_type.proto\x1a\x16v1/stock/carrier.proto\x1a v1/stock/procurement_group.proto\x1a\x19v1/stock/attachment.proto\x1a\x15v1/stock/client.proto\x1a\x1ev1/stock/delivery_method.proto\x1a\x14v1/stock/order.proto\x1a\x1dv1/stock/payment_method.proto\x1a\x13v1/stock/sale.proto\x1a\x13v1/stock/user.proto\x1a\x16v1/stock/address.proto"\x95\x0e\n\x07Picking\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12I\n\x0cpicking_type\x18\x03 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12>\n\x08location\x18\x04 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x43\n\rlocation_dest\x18\x05 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12J\n\x10\x61ttachment_guide\x18\x06 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment\x12L\n\x12\x61ttachment_invoice\x18\x07 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment\x12\x0e\n\x06origin\x18\x08 \x01(\t\x12:\n\x16\x64\x61te_start_preparation\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdate_done\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0escheduled_date\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16time_total_preparation\x18\x0c \x01(\x02\x12\x15\n\rtime_assigned\x18\r \x01(\x02\x12;\n\x07\x63\x61rrier\x18\x0e \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.carrier.Carrier\x12\x31\n\rdate_delivery\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14\x63\x61rrier_tracking_ref\x18\x10 \x01(\t\x12L\n\x05group\x18\x11 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup\x12\x0e\n\x06weight\x18\x12 \x01(\x02\x12\x17\n\x0fshipping_weight\x18\x13 \x01(\x02\x12\r\n\x05state\x18\x14 \x01(\t\x12@\n\ndependency\x18\x15 \x01(\x0b\x32,.pro.omni.oms.api.common.base.ObjectResponse\x12\x0c\n\x04note\x18\x16 \x01(\t\x12\x1c\n\x14\x63\x61rrier_tracking_url\x18\x17 \x01(\t\x12.\n\rinfo_receives\x18\x18 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x0e\x64\x61te_validated\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0fsale_date_order\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x06\x63lient\x18\x1b \x01(\x0b\x32(.pro.omni.oms.api.v1.stock.client.Client\x12R\n\x0f\x64\x65livery_method\x18\x1c \x01(\x0b\x32\x39.pro.omni.oms.api.v1.stock.delivery_method.DeliveryMethod\x12\x35\n\x05order\x18\x1d \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.order.Order\x12O\n\x0epayment_method\x18\x1e \x01(\x0b\x32\x37.pro.omni.oms.api.v1.stock.payment_method.PaymentMethod\x12\x32\n\x04sale\x18\x1f \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.sale.Sale\x12\x32\n\x04user\x18  \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.user.User\x12\x44\n\x10shipping_address\x18! \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.address.Address\x12*\n\x06\x61\x63tive\x18" \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\twarehouse\x18# \x01(\x0b\x32,.pro.omni.oms.api.common.base.ObjectResponse\x12\x13\n\x0b\x65xternal_id\x18$ \x01(\t\x12?\n\x0cobject_audit\x18% \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x99\x08\n\x14PickingCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x18\n\x10location_dest_id\x18\x04 \x01(\x05\x12\x1b\n\x13\x61ttachment_guide_id\x18\x05 \x01(\x05\x12\x1d\n\x15\x61ttachment_invoice_id\x18\x06 \x01(\x05\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12:\n\x16\x64\x61te_start_preparation\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdate_done\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0escheduled_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16time_total_preparation\x18\x0b \x01(\x02\x12\x15\n\rtime_assigned\x18\x0c \x01(\x02\x12\x12\n\ncarrier_id\x18\r \x01(\x05\x12\x31\n\rdate_delivery\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14\x63\x61rrier_tracking_ref\x18\x0f \x01(\t\x12\x10\n\x08group_id\x18\x10 \x01(\x05\x12\x0e\n\x06weight\x18\x11 \x01(\x02\x12\x17\n\x0fshipping_weight\x18\x12 \x01(\x02\x12\r\n\x05state\x18\x13 \x01(\t\x12\x15\n\rdependency_id\x18\x14 \x01(\x05\x12\x0c\n\x04note\x18\x15 \x01(\t\x12\x1c\n\x14\x63\x61rrier_tracking_url\x18\x16 \x01(\t\x12\x32\n\x0e\x64\x61te_validated\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0fsale_date_order\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tclient_id\x18\x19 \x01(\t\x12\x1a\n\x12\x64\x65livery_method_id\x18\x1a \x01(\t\x12\x10\n\x08order_id\x18\x1b \x01(\x05\x12\x19\n\x11payment_method_id\x18\x1c \x01(\t\x12\x0f\n\x07sale_id\x18\x1d \x01(\x05\x12\x0f\n\x07user_id\x18\x1e \x01(\t\x12\x1d\n\x15shipping_address_code\x18\x1f \x01(\t\x12\x14\n\x0cwarehouse_id\x18  \x01(\x05\x12.\n\rinfo_receives\x18! \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x65xternal_id\x18" \x01(\t\x12\x36\n\x07\x63ontext\x18# \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"\xf0\x02\n\x12PickingReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13PickingReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08pickings\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"\x8b\x01\n\x14PickingUpdateRequest\x12;\n\x07picking\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"Z\n\x14PickingDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15PickingDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\\\n\x16ValidatePickingRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x01\n\x17ValidatePickingResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct"Y\n\x13PickingMovesRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x88\x01\n\x14PickingMovesResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xb6\x06\n\x0ePickingService\x12\x84\x01\n\rPickingCreate\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingCreateResponse"\x00\x12~\n\x0bPickingRead\x12\x35.pro.omni.oms.api.v1.stock.picking.PickingReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.picking.PickingReadResponse"\x00\x12\x84\x01\n\rPickingUpdate\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingUpdateResponse"\x00\x12\x84\x01\n\rPickingDelete\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingDeleteResponse"\x00\x12\x8a\x01\n\x0fValidatePicking\x12\x39.pro.omni.oms.api.v1.stock.picking.ValidatePickingRequest\x1a:.pro.omni.oms.api.v1.stock.picking.ValidatePickingResponse"\x00\x12\x81\x01\n\x0cPickingMoves\x12\x36.pro.omni.oms.api.v1.stock.picking.PickingMovesRequest\x1a\x37.pro.omni.oms.api.v1.stock.picking.PickingMovesResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.picking_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKING"]._serialized_start = 489
    _globals["_PICKING"]._serialized_end = 2302
    _globals["_PICKINGCREATEREQUEST"]._serialized_start = 2305
    _globals["_PICKINGCREATEREQUEST"]._serialized_end = 3354
    _globals["_PICKINGCREATERESPONSE"]._serialized_start = 3357
    _globals["_PICKINGCREATERESPONSE"]._serialized_end = 3516
    _globals["_PICKINGREADREQUEST"]._serialized_start = 3519
    _globals["_PICKINGREADREQUEST"]._serialized_end = 3887
    _globals["_PICKINGREADRESPONSE"]._serialized_start = 3890
    _globals["_PICKINGREADRESPONSE"]._serialized_end = 4107
    _globals["_PICKINGUPDATEREQUEST"]._serialized_start = 4110
    _globals["_PICKINGUPDATEREQUEST"]._serialized_end = 4249
    _globals["_PICKINGUPDATERESPONSE"]._serialized_start = 4252
    _globals["_PICKINGUPDATERESPONSE"]._serialized_end = 4411
    _globals["_PICKINGDELETEREQUEST"]._serialized_start = 4413
    _globals["_PICKINGDELETEREQUEST"]._serialized_end = 4503
    _globals["_PICKINGDELETERESPONSE"]._serialized_start = 4505
    _globals["_PICKINGDELETERESPONSE"]._serialized_end = 4603
    _globals["_VALIDATEPICKINGREQUEST"]._serialized_start = 4605
    _globals["_VALIDATEPICKINGREQUEST"]._serialized_end = 4697
    _globals["_VALIDATEPICKINGRESPONSE"]._serialized_start = 4700
    _globals["_VALIDATEPICKINGRESPONSE"]._serialized_end = 4839
    _globals["_PICKINGMOVESREQUEST"]._serialized_start = 4841
    _globals["_PICKINGMOVESREQUEST"]._serialized_end = 4930
    _globals["_PICKINGMOVESRESPONSE"]._serialized_start = 4933
    _globals["_PICKINGMOVESRESPONSE"]._serialized_end = 5069
    _globals["_PICKINGSERVICE"]._serialized_start = 5072
    _globals["_PICKINGSERVICE"]._serialized_end = 5894
# @@protoc_insertion_point(module_scope)
